# Changelog
All notable changes to this project will be documented in this file.

## [0.0.13] - 2020-09-16
### Added
  * Created changelog
  * Fixed job status error string format
  * Added black for code  formatting
  * Fixed python semantics
  * Moved zipfile out from webapi class